summaryrefslogtreecommitdiffstats
path: root/tdeio/tdeio/kshellcompletion.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdeio/tdeio/kshellcompletion.h')
-rw-r--r--tdeio/tdeio/kshellcompletion.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/tdeio/tdeio/kshellcompletion.h b/tdeio/tdeio/kshellcompletion.h
index fa90c509e..a23fbe78e 100644
--- a/tdeio/tdeio/kshellcompletion.h
+++ b/tdeio/tdeio/kshellcompletion.h
@@ -56,10 +56,10 @@ public:
TQString makeCompletion(const TQString &text);
protected:
// Called by KCompletion
void postProcessMatch( TQString *match ) const;
void postProcessMatches( TQStringList *matches ) const;
- void postProcessMatches( KCompletionMatches *matches ) const;
+ void postProcessMatches( TDECompletionMatches *matches ) const;
private:
// Find the part of text that should be completed
@@ -56,10 +56,10 @@ public:
TQString makeCompletion(const TQString &text);
protected:
- // Called by KCompletion
+ // Called by TDECompletion
void postProcessMatch( TQString *match ) const;
void postProcessMatches( TQStringList *matches ) const;